@@ -3,7 +3,6 @@ from moxn.telemetry.client import TelemetryClient
 import logging
 from functools import lru_cache
 from pathlib import Path
-from typing import Callable, Coroutine
 import httpx
 
 from moxn.exceptions import MoxnSchemaValidationError
@@ -99,14 +98,13 @@ class MoxnClient:
         self._context_depth += 1
         if self._client is None:
             self._client = self._create_client()
+        await self.telemetry_client.start()
         return self
 
     async def __aexit__(self, exc_type, exc_val, exc_tb) -> None:
         self._context_depth -= 1
         if self._context_depth == 0:
-            # ensure all telemetry is sent before tear‐down
-            await self.telemetry_client._dispatcher.flush()
-            await self.telemetry_client.aclose()
+            await self.telemetry_client.stop()
             await self.stop_polling()
             await self.close()
 
@@ -506,7 +504,7 @@ class MoxnClient:
         Example:
             async with client.span(name="agent_task", prompt_instance=prompt_instance, kind="agent"):
                 # Do work within the span
-                await client.log_event(llm_event)
+                await client.log_telemetry_event(llm_event)
         """
         if name is None:
             name = prompt_instance.base_prompt.name
@@ -518,13 +516,6 @@ class MoxnClient:
         ) as span_context:
             yield span_context
 
-    # deprecate
-    @property
-    def log_event(
-        self,
-    ) -> Callable[[LLMEvent, UUID | None], Coroutine[None, None, None]]:
-        return self.log_telemetry_event
-
     async def log_telemetry_event(
         self,
         event: LLMEvent,
@@ -570,9 +561,11 @@ class MoxnClient:
             logger.error(f"Signed URL request failed: {e}", exc_info=True)
             raise RuntimeError("Failed to get signed URL for telemetry data") from e
 
-    async def flush(self, timeout: float | None = 30.0) -> None:
+    async def flush(self, timeout: float | None = None) -> None:
         """
-        Await in‐flight telemetry logs (call this at process‐exit,
+        Await in-flight telemetry logs (call this at process-exit,
         lambda return, or FASTAPI shutdown).
         """
+        if timeout is None:
+            timeout = self.settings.timeout
         await self.telemetry_client._dispatcher.flush(timeout)
