@@ -13,7 +13,7 @@ from openai.types.chat import (
     ChatCompletionUserMessageParam,
 )
 from moxn.telemetry.utils import unpack_llm_response_content
-
+from moxn.base_models.utils import infer_image_mime
 from moxn import base_models
 from moxn.base_models.content import (
     ImageContentBase64,
@@ -21,6 +21,7 @@ from moxn.base_models.content import (
     MessageRole,
     Provider,
     TextContent,
+    ImageContentUrl,
 )
 
 OPENAI_MESSAGE_CLASSES = {
@@ -45,7 +46,7 @@ class Message(base_models._Message):
         }
 
     def validate_variables(
-        self, variables: dict[str, str | int | float | None | bool]
+        self, variables: dict[str, str | int | float | None | bool | dict]
     ) -> None:
         """Validate that all required variables are provided"""
         missing_vars = self.variables - set(variables.keys())
@@ -57,7 +58,7 @@ class Message(base_models._Message):
         self,
         block: dict[str, Any],
         provider: Literal[Provider.ANTHROPIC],
-        variables: dict[str, str | int | float | None | bool],
+        variables: dict[str, str | int | float | None | bool | dict],
     ) -> TextBlockParam | ImageBlockParam: ...
 
     @overload
@@ -65,14 +66,14 @@ class Message(base_models._Message):
         self,
         block: dict[str, Any],
         provider: Literal[Provider.OPENAI],
-        variables: dict[str, str | int | float | None | bool],
+        variables: dict[str, str | int | float | None | bool | dict],
     ) -> ChatCompletionContentPartParam: ...
 
     def _process_block(
         self,
         block: dict[str, Any],
         provider: Provider,
-        variables: dict[str, str | int | float | None | bool],
+        variables: dict[str, str | int | float | None | bool | dict],
     ) -> TextBlockParam | ImageBlockParam | ChatCompletionContentPartParam:
         """
         Process a single content block
@@ -97,16 +98,28 @@ class Message(base_models._Message):
                 raise ValueError(f"Unsupported provider: {provider}")
 
         elif block_type == "image":
+            inferred_mime = infer_image_mime(block["content"])
+            if inferred_mime is None or inferred_mime not in [
+                "image/jpeg",
+                "image/png",
+                "image/gif",
+                "image/webp",
+            ]:
+                raise ValueError("Unsupported image format")
+            cast_inferred_mime = cast(
+                Literal["image/png", "image/jpeg", "image/gif", "image/webp"],
+                inferred_mime,
+            )
             if provider == Provider.ANTHROPIC:
                 return ImageContentBase64(
                     type="image_base64",
-                    media_type=block["metadata"]["mime"],
+                    media_type=cast_inferred_mime,
                     data=block["content"],
                 ).to_provider_content_block(Provider.ANTHROPIC)
             elif provider == Provider.OPENAI:
                 return ImageContentBase64(
                     type="image_base64",
-                    media_type=block["metadata"]["mime"],
+                    media_type=cast_inferred_mime,
                     data=block["content"],
                 ).to_provider_content_block(Provider.OPENAI)
             else:
@@ -116,6 +129,56 @@ class Message(base_models._Message):
             var_name = block["metadata"]["conf"]["name"]
             var_value = variables[var_name]
 
+            # Check if this is an image variable
+            var_type = block["property"].get("type")
+            if var_type == "image":
+                var_format = (
+                    block["property"]["type"].get("constraints", {}).get("format", "")
+                )
+
+                # Handle image URL variables
+                if var_format == "image-url":
+                    if not isinstance(var_value, str):
+                        raise ValueError(
+                            f"Expected URL string for image variable {var_name}, got {type(var_value)}"
+                        )
+
+                    if provider == Provider.ANTHROPIC:
+                        return ImageContentUrl(
+                            image_url=var_value
+                        ).to_provider_content_block(Provider.ANTHROPIC)
+                    elif provider == Provider.OPENAI:
+                        return ImageContentUrl(
+                            image_url=var_value
+                        ).to_provider_content_block(Provider.OPENAI)
+
+                # Handle base64 image variables
+                elif var_format == "image-base64":
+                    if (
+                        not isinstance(var_value, dict)
+                        or "data" not in var_value
+                        or "media_type" not in var_value
+                    ):
+                        raise ValueError(
+                            f"Expected dict with 'data' and 'media_type' for base64 image variable {var_name}"
+                        )
+
+                    if provider == Provider.ANTHROPIC:
+                        return ImageContentBase64(
+                            type="image_base64",
+                            media_type=var_value["media_type"],
+                            data=var_value["data"],
+                        ).to_provider_content_block(Provider.ANTHROPIC)
+                    elif provider == Provider.OPENAI:
+                        return ImageContentBase64(
+                            type="image_base64",
+                            media_type=var_value["media_type"],
+                            data=var_value["data"],
+                        ).to_provider_content_block(Provider.OPENAI)
+                else:
+                    raise ValueError(f"Unsupported image format: {var_format}")
+
+            # Handle regular text variables (existing behavior)
             text = str(var_value) if var_value is not None else ""
 
             if provider == Provider.ANTHROPIC:
