@@ -467,18 +467,6 @@ class PromptInstance:
         else:
             raise ValueError(f"Unsupported provider: {provider}")
 
-    @overload
-    def to_provider_payload(
-        self,
-        provider: Literal[base_models.Provider.ANTHROPIC],
-    ) -> dict[str, str | list[dict[str, Any]]]: ...
-
-    @overload
-    def to_provider_payload(
-        self,
-        provider: Literal[base_models.Provider.OPENAI],
-    ) -> dict[str, list[dict[str, Any]]]: ...
-
     def to_provider_payload(
         self,
         provider: base_models.Provider,
@@ -488,21 +476,21 @@ class PromptInstance:
             return cast(
                 dict[str, Any],
                 self.to_provider_messages(base_models.Provider.ANTHROPIC).model_dump(
-                    by_alias=True
+                    by_alias=True, mode="json"
                 ),
             )
         elif provider == base_models.Provider.OPENAI:
             return cast(
                 dict[str, Any],
                 self.to_provider_messages(base_models.Provider.OPENAI).model_dump(
-                    by_alias=True
+                    by_alias=True, mode="json"
                 ),
             )
         else:
             raise ValueError(f"Unsupported provider: {provider}")
 
     @overload
-    async def create_llm_event(
+    async def _create_llm_event(
         self,
         response: AnthropicMessage,
         provider: Literal[base_models.Provider.ANTHROPIC],
@@ -510,14 +498,14 @@ class PromptInstance:
     ) -> LLMEvent: ...
 
     @overload
-    async def create_llm_event(
+    async def _create_llm_event(
         self,
         response: ChatCompletion,
         provider: Literal[base_models.Provider.OPENAI],
         attributes: dict | None = None,
     ) -> LLMEvent: ...
 
-    async def create_llm_event(
+    async def _create_llm_event(
         self,
         response: ChatCompletion | AnthropicMessage,
         provider: base_models.Provider,
@@ -552,3 +540,28 @@ class PromptInstance:
             ),
             attributes=attributes,
         )
+
+    async def create_llm_event(
+        self,
+        response: ChatCompletion | AnthropicMessage | Any,
+        provider: base_models.Provider,
+        attributes: dict | None = None,
+    ) -> LLMEvent:
+        """Creates an LLM event from the current state."""
+        if not isinstance(response, (ChatCompletion, AnthropicMessage)):
+            try:
+                response = ChatCompletion.model_validate(response.model_dump())
+            except Exception as _:
+                raise ValueError(f"Unsupported response type: {type(response)}")
+        if provider == base_models.Provider.OPENAI:
+            assert isinstance(response, ChatCompletion)
+            return await self._create_llm_event(
+                response, base_models.Provider.OPENAI, attributes
+            )
+        elif provider == base_models.Provider.ANTHROPIC:
+            assert isinstance(response, AnthropicMessage)
+            return await self._create_llm_event(
+                response, base_models.Provider.ANTHROPIC, attributes
+            )
+        else:
+            raise ValueError(f"Unsupported response type: {type(response)}")
