@@ -1,5 +1,6 @@
 from pydantic import HttpUrl, Field, SecretStr
 from pydantic_settings import BaseSettings, SettingsConfigDict
+from functools import lru_cache
 
 
 class MoxnSettings(BaseSettings):
@@ -11,7 +12,7 @@ class MoxnSettings(BaseSettings):
     base_api_route: HttpUrl = Field(
         default=HttpUrl("https://marksweissma--moxn-api-fastapi-app.modal.run")
     )
-    timeout: float = Field(default=60.0, description="Prompt timeout in seconds")
+    timeout: float = Field(default=30.0, description="Prompt timeout in seconds")
 
     model_config = SettingsConfigDict(
         frozen=True,
@@ -20,3 +21,8 @@ class MoxnSettings(BaseSettings):
         env_prefix="MOXN_",
         env_file_encoding="utf-8",
     )
+
+
+@lru_cache(maxsize=1)
+def get_moxn_settings() -> MoxnSettings:
+    return MoxnSettings()  # type: ignore
